import { Header } from '@/views/Service'
import Link from 'next/link'
import { fetchServices, fetchService } from '@/lib/contentful'
import { removeFromObjRecursive, replaceEmailsRecursive } from '@/lib/utils'
import { documentToHtmlString } from '@contentful/rich-text-html-renderer'
import { IconChevronLeft } from '@tabler/icons'

export default function ({ service }) {
  return (
    <div className={'mx-auto max-w-screen-xl'}>
      <nav className="relative max-w-7xl flex">
        <div className="flex items-center flex-1">
          <div className="flex items-center justify-between w-full md:w-auto">
            <div className="hidden lg:flex">
              <Link href="/resources" passHref>
                <a className={'text-lg font-bold text-yellow-400 hover:text-gray-900'}>
                  Zurück zur Übersicht
                </a>
              </Link>
            </div>
            <div className="flex lg:hidden">
              <Link href="/resources" passHref>
                <a>
                  <IconChevronLeft
                    className="m-6 text-yellow-400 hover:text-gray-900"
                    aria-hidden="true"
                  />
                </a>
              </Link>
            </div>
          </div>
        </div>
      </nav>
      <Header
        contact={{
          name: service.contactInformation.fields.name,
          mailTo: service.contactInformation.fields.eMail
        }}
        img={{
          src: service?.logo?.fields.file.url,
          alt: service?.logo?.fields.name
        }}
        title={service.name}
        description={documentToHtmlString(service.description)}
        developer={{
          name: service.developer.fields.name,
          link: service.developer.fields.link
        }}
        status={service.status}
        documentationURL={service.documentation}
        sourceURL={service.sourcecodeURL}
        resources={service.ressource?.map(resource => { return { name: resource.fields.name, slug: resource.fields.slug } })
        }
      />
    </div>
  )
}

export async function getStaticProps({ params }) {
  const service = await fetchService(params.serviceName)
  // remove unwanted data and encrypt eMails
  const nosys = removeFromObjRecursive('sys', service.fields)
  const fields = replaceEmailsRecursive('eMail', nosys)
  return {
    props: {
      service: fields
    }
  }
}

export async function getStaticPaths() {
  const servicePaths = (await fetchServices()).map((service) => {
    return { params: { serviceName: service.fields.slug } }
  })

  return {
    paths: servicePaths,
    fallback: false
  }
}
