import { IconSend, IconRoute, IconSteeringWheel, IconBug, IconManualGearbox, IconBrandOpenSource, IconRocket } from '@tabler/icons'
import Link from 'next/link'

const featuredModules = [
  {
    name: 'Standards und Schnittstellen',
    href: 'https://docs.fitko.de/standards-und-schnittstellen/',
    description:
      'Im Rahmen der Umsetzung des Portalverbunds wurden die Kommunikationsbeziehungen zwischen den verschiedenen Basisdiensten wie Servicekonten, Postfächern und ePayment-Lösungen analysiert und in einer Übersicht der eingesetzten Standards und Schnittstellen dokumentiert.',
    icon: IconSteeringWheel,
  },
  {
    name: 'Submission-API',
    href: 'https://docs.fitko.de/fit-connect/docs/apis/submission-api',
    description:
      'Über den FIT-Connect Zustelldienst können Anträge für Verwaltungsleistungen maschinenlesbar an die fachlich zuständige Behörde übermittelt werden. Der Zustelldienst stellt hierfür die Submission API bereit. Sendende Systeme können sich über eine erfolgreiche Zustellung über ein Ereignisprotokoll informieren.',
    icon: IconSend,
  },
  {
    name: 'Routing-API',
    href: 'https://docs.fitko.de/fit-connect/docs/apis/routing-api',
    description:
      'Um einen Antrag maschinenlesbar an die fachlich zuständige Stelle sicher zu übermitteln und die technischen Parameter der empfangenden Behörde zu ermitteln, kann über die Routing API die zuständigen Stelle und die Adresse des zuständigen Zustelldienstes ermittelt werden. Die Ermittlung dieser technischen Parameter erfolgt über eine Anfrage an den FIT-Connect Routingdienst.',
    icon: IconRoute,
  },
]

const blogEnties =
  [{
    headline: 'Über das Föderale Entwicklungsportal',
    icon: IconManualGearbox,
    text: `Das Föderale Entwicklungsportal stellt eine <strong>zentrale Anlaufstelle für Softwareentwickler:innen</strong> dar.
          Bei der Umsetzung von digitalen Anwendungen für die Verwaltung spielen Entwickler:innen eine zentrale Rolle. Sie müssen in die Lage versetzt werden, schnell und effizient nachnutzbare Lösungen zu schaffen.
          Primäre Zielgruppe des föderalen Entwicklungsportals sind daher Softwareentwickler:innen, die Software für die öffentliche Verwaltung im Kontext föderaler <strong>IT-Infrastrukturen von Bund und Ländern </strong>entwickeln.
          <br/>
          <br/>
          Um die bestehenden Hürden bei der <strong>Beschaffung von Informationen über technische Rahmenbedingungen sowie existierender Standards und Schnittstellen</strong> zu reduzieren, werden bestehende Informationsangebote in diesem Portal gebündelt und durch zusätzliche Informationsangebote ergänzt.
          Eine Öffnung der bestehenden Bemühungen für möglichst alle Akteur:innen sowie deren effektive Koordination und Kooperation ist nötig, um die Stärken der föderal organisierten deutschen Verwaltung mit ihren verteilten Ressourcen effizient zu nutzen.
          <br/>
          <br/>
          Das Föderale Entwicklungsportal <strong>senkt damit Entwicklungsaufwände</strong> bei allen Beteiligten und beschleunigt dadurch Umsetzungsprojekte.
          Damit wird die Entwicklung eines innovativen Lösungsökosystems gefördert und ein „Single-Point-of-Truth“ geschaffen, an dem sich alle Entwickler:innen, Leistungs- und Umsetzungsverantwortliche orientieren können.
          Das Föderale Entwicklungsportal ist Teil des IT-Planungsrats-Projekts <a href='https://www.fitko.de/projektmanagement/fit-connect'>FIT-Connect</a> und wird aus Mitteln des <a href='https://www.fitko.de/foederale-koordination/digitalisierungsbudget'>Digitalisierungsbudgets</a> von der <a href='https://www.fitko.de/'>Föderalen IT-Kooperation</a> (FITKO) entwickelt.`,
  },
  {
    headline: 'Du möchtest Fehler oder Verbesserungsvorschläge melden?',
    icon: IconBrandOpenSource,
    text: `Im Auftrag des <a href='https://www.it-planungsrat.de/'>IT-Planungsrats</a> betreibt die Föderale IT-Kooperation (FITKO) eine Reihe von <a href='https://www.fitko.de/produktmanagement'>Produkten</a> und steuert <a href='https://www.fitko.de/projektmanagement'>Projekte</a>, die noch zu Produkten werden wollen.<br/><br/>
            Um dabei immer besser zu werden, sind wir auf Dein Feedback angewiesen! In unserem Issue-Tracker im <i>Open Source Code Repository der öffentlichen Verwaltung</i> kannst Du Fehler oder Verbesserungsvorschläge zu Komponenten der Föderalen IT-Infrastruktur melden.<br/><br/>
            Der Issue-Tracker soll bestehende Feedback-Möglichkeiten nicht ersetzen, sondern diese ergänzen. Wir versuchen dennoch gerne, Dein Anliegen an die richtige Ansprechperson zu vermitteln. Bitte habe Verständnis, wenn dies manchmal etwas Zeit in Anspruch nimmt. Wir experimentieren hier gerade mit neuen Feedback-Möglichkeiten und bekommen im Alltagsgeschäft natürlich auch Feedback über etablierte Kanäle, das es ebenfalls zu bedienen gilt.<br/><br/>
            Bitte beachte, dass Dein Feedback öffentlich einsehbar sein wird.<br/><br/>
            Schau vor Deinem Feedback bitte <a href='https://gitlab.opencode.de/fitko/feedback/-/issues'>in die Liste der bestehenden Issues</a> und erstelle erst dann <a href='https://gitlab.opencode.de/fitko/feedback/-/issues/new'>ein neues Issue</a>.<br/><br/>
            Danke! 😊`,
  },
  {
    headline: 'Du hast Fragen oder neue Ideen, die Du gerne diskutieren möchtest?',
    icon: IconBrandOpenSource,
    text: `Im <a href='https://discourse.opencode.de/'>Forum des Open Source Code Repository</a> ist Platz dafür. Wir freuen uns auf Deinen Beitrag!`,
  },
  ];

export default () => {
  return (
    <div className="bg-white">
      <div className="relative pb-32 bg-gray-800">
        <div className="absolute inset-0 bg-yellow-400">
          <div className="h-full bg-[length:250px] bg-banner-texture" />
          <div
            className="absolute inset-0 bg-gray-200 mix-blend-multiply"
            aria-hidden="true"
          />
        </div>
        {blogEnties.map((blogEntry) => (
          <section className="relative max-w-7xl mx-auto pt-24 pb-14 px-4 sm:px-6 lg:px-8">
            <div className='flex justify-start'>
              <div className="h-16 w-16 m-2.5 p-5 bg-yellow-400 rounded-xl shadow-lg">
                <blogEntry.icon
                  className="h-6 w-6 text-white"
                />
              </div>
              <h1 className="overflow-hidden py-1 sm:py-0.5 m-4 text-2xl sm:text-3xl font-extrabold tracking-tight text-white drop-shadow-md">
                {blogEntry.headline}
              </h1>
            </div>
            <p className="cms-blog-text p-8 mt-6 max-w-7xl text-lg text-gray-800 bg-white rounded-2xl" dangerouslySetInnerHTML={{ __html: blogEntry.text }} />
          </section>
        ))}

        <section className="relative max-w-7xl mx-auto pt-14 pb-24 px-4 sm:px-6 lg:px-8">
          <div className='flex justify-start'>
            <div className="h-16 w-16 m-2.5 p-5 bg-yellow-400 rounded-xl shadow-lg">
              <IconRocket
                className="h-6 w-6 text-white"
              />
            </div>
            <h1 className="overflow-hidden py-1 sm:py-0.5 m-4 text-2xl sm:text-3xl font-extrabold tracking-tight text-white drop-shadow-md">
              Direkt loslegen!
            </h1>
          </div>
          <p className="p-8 mt-6 max-w-7xl text-lg text-gray-800 bg-white rounded-t-2xl">
            Mit den folgenden Ressourcen kannst Du direkt loslegen und mehr über die Föderale IT-Infrastruktur von Bund und Ländern erfahren und Anwendungen für die Öffentliche Verwaltung erstellen. Pespektivisch werden an dieser Stelle konkrete Entwicklungsszenarien mit den jeweils dafür benötigten Entwicklungsressourcen zusammengestellt.
          </p>
          <div className="p-6 bg-gray-50 rounded-bl-2xl rounded-br-2xl md:px-8">
            <Link href="/resources" passHref>
              <a className="text-base font-bold text-yellow-400 hover:text-yellow-600">
                Zu den Entwicklungsressourcen<span aria-hidden="true"> &rarr;</span>
              </a>
            </Link>
          </div>
        </section>
      </div>

      {/* Overlapping cards */}
      <section className="-mt-32 max-w-7xl mx-auto relative z-10 pb-32 px-4 sm:px-6 lg:px-8">
        <div className="grid grid-cols-1 gap-y-20 lg:grid-cols-3 lg:gap-y-0 lg:gap-x-8">
          {featuredModules.map((link) => (
            <div
              key={link.name}
              className="flex flex-col bg-white rounded-2xl shadow-xl"
            >
              <div className="flex-1 relative pt-16 px-6 pb-8 md:px-8">
                <div className="absolute top-0 p-5 inline-block bg-yellow-400 rounded-xl shadow-lg transform -translate-y-1/2">
                  <link.icon
                    className="h-6 w-6 text-white"
                  />
                </div>
                <h2 className="text-xl font-medium text-gray-900">
                  {link.name}
                </h2>
                <p className="mt-4 text-base text-gray-500">
                  {link.description}
                </p>
              </div>
              <div className="p-6 bg-gray-50 rounded-bl-2xl rounded-br-2xl md:px-8">
                <a
                  href={link.href}
                  className="text-base font-medium text-yellow-400 hover:text-yellow-600"
                >
                  Mehr erfahren<span aria-hidden="true"> &rarr;</span>
                </a>
              </div>
            </div>
          ))}
        </div>
      </section>
    </div>
  )
}
